@@ -4,6 +4,7 @@ use syn::{self};
 
 pub fn create_public_struct(ast: &syn::DeriveInput) -> TokenStream {
     let name = &ast.ident;
+    let generics = &ast.generics;
 
     let fields = match &ast.data {
         syn::Data::Struct(syn::DataStruct { fields: syn::Fields::Named(fields), .. }) => &fields.named,
@@ -13,7 +14,7 @@ pub fn create_public_struct(ast: &syn::DeriveInput) -> TokenStream {
     let field_type = fields.iter().map(|field| &field.ty);
 
     TokenStream::from(quote! {
-        pub struct #name {
+        pub struct #name #generics {
             #(
                 pub #field_name: #field_type,
             )*
